@@ -7,6 +7,7 @@ from .jira import Jira
 from .marketplace import MarketPlace
 from .portfolio import Portfolio
 from .service_desk import ServiceDesk
+from .xray import Xray
 
 __all__ = [
     'Confluence',
@@ -17,5 +18,6 @@ __all__ = [
     'Stash',
     'Crowd',
     'ServiceDesk',
-    'MarketPlace'
+    'MarketPlace',
+    'Xray'
 ]
